summaryrefslogtreecommitdiffstats
path: root/k9decmpeg/motion_comp_mmx.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /k9decmpeg/motion_comp_mmx.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'k9decmpeg/motion_comp_mmx.cpp')
-rwxr-xr-xk9decmpeg/motion_comp_mmx.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/k9decmpeg/motion_comp_mmx.cpp b/k9decmpeg/motion_comp_mmx.cpp
index 97828c4..f3c30ef 100755
--- a/k9decmpeg/motion_comp_mmx.cpp
+++ b/k9decmpeg/motion_comp_mmx.cpp
@@ -52,7 +52,7 @@
*/
/* some rounding constants */
-static mmx_t mask1 = {0xfefefefefefefefeLL};
+static mmx_t tqmask1 = {0xfefefefefefefefeLL};
static mmx_t round4 = {0x0002000200020002LL};
/*
@@ -81,7 +81,7 @@ static inline void mmx_average_2_U8 (uint8_t * dest, const uint8_t * src1,
movq_r2r (mm3, mm4); /* copy 8 src2 bytes */
pxor_r2r (mm1, mm3); /* xor src1 and src2 */
- pand_m2r (mask1, mm3); /* mask lower bits */
+ pand_m2r (tqmask1, mm3); /* tqmask lower bits */
psrlq_i2r (1, mm3); /* /2 */
por_r2r (mm2, mm4); /* or src1 and src2 */
psubb_r2r (mm3, mm4); /* subtract subresults */
@@ -104,14 +104,14 @@ static inline void mmx_interp_average_2_U8 (uint8_t * dest,
movq_r2r (mm5, mm6); /* copy 8 src2 bytes */
pxor_r2r (mm3, mm5); /* xor src1 and src2 */
- pand_m2r (mask1, mm5); /* mask lower bits */
+ pand_m2r (tqmask1, mm5); /* tqmask lower bits */
psrlq_i2r (1, mm5); /* /2 */
por_r2r (mm4, mm6); /* or src1 and src2 */
psubb_r2r (mm5, mm6); /* subtract subresults */
movq_r2r (mm6, mm5); /* copy subresult */
pxor_r2r (mm1, mm5); /* xor srcavg and dest */
- pand_m2r (mask1, mm5); /* mask lower bits */
+ pand_m2r (tqmask1, mm5); /* tqmask lower bits */
psrlq_i2r (1, mm5); /* /2 */
por_r2r (mm2, mm6); /* or srcavg and dest */
psubb_r2r (mm5, mm6); /* subtract subresults */
@@ -228,7 +228,7 @@ static inline void mmx_interp_average_4_U8 (uint8_t * dest,
movq_r2r (mm1,mm2); /* copy subresult */
pxor_r2r (mm1, mm3); /* xor srcavg and dest */
- pand_m2r (mask1, mm3); /* mask lower bits */
+ pand_m2r (tqmask1, mm3); /* tqmask lower bits */
psrlq_i2r (1, mm3); /* /2 */
por_r2r (mm2, mm4); /* or srcavg and dest */
psubb_r2r (mm3, mm4); /* subtract subresults */
@@ -636,7 +636,7 @@ static inline void MC_avg2_16 (int height, uint8_t * dest, const uint8_t * ref,
} while (--height);
}
-static mmx_t mask_one = {0x0101010101010101LL};
+static mmx_t tqmask_one = {0x0101010101010101LL};
static inline void MC_put4_8 (int height, uint8_t * dest, const uint8_t * ref,
const int stride, const int cpu)
@@ -664,7 +664,7 @@ static inline void MC_put4_8 (int height, uint8_t * dest, const uint8_t * ref,
pand_r2r (mm5, mm7);
pavg_r2r (mm2, mm0);
- pand_m2r (mask_one, mm7);
+ pand_m2r (tqmask_one, mm7);
psubusb_r2r (mm7, mm0);
@@ -695,7 +695,7 @@ static inline void MC_put4_16 (int height, uint8_t * dest, const uint8_t * ref,
movq_r2r (mm0, mm6);
pxor_r2r (mm2, mm6);
pand_r2r (mm6, mm7);
- pand_m2r (mask_one, mm7);
+ pand_m2r (tqmask_one, mm7);
pavg_r2r (mm2, mm0);
psubusb_r2r (mm7, mm0);
movq_r2m (mm0, *dest);
@@ -714,7 +714,7 @@ static inline void MC_put4_16 (int height, uint8_t * dest, const uint8_t * ref,
movq_r2r (mm0, mm6);
pxor_r2r (mm2, mm6);
pand_r2r (mm6, mm7);
- pand_m2r (mask_one, mm7);
+ pand_m2r (tqmask_one, mm7);
pavg_r2r (mm2, mm0);
psubusb_r2r (mm7, mm0);
ref += stride;
@@ -741,7 +741,7 @@ static inline void MC_avg4_8 (int height, uint8_t * dest, const uint8_t * ref,
movq_r2r (mm0, mm6);
pxor_r2r (mm2, mm6);
pand_r2r (mm6, mm7);
- pand_m2r (mask_one, mm7);
+ pand_m2r (tqmask_one, mm7);
pavg_r2r (mm2, mm0);
psubusb_r2r (mm7, mm0);
movq_m2r (*dest, mm1);
@@ -770,7 +770,7 @@ static inline void MC_avg4_16 (int height, uint8_t * dest, const uint8_t * ref,
movq_r2r (mm0, mm6);
pxor_r2r (mm2, mm6);
pand_r2r (mm6, mm7);
- pand_m2r (mask_one, mm7);
+ pand_m2r (tqmask_one, mm7);
pavg_r2r (mm2, mm0);
psubusb_r2r (mm7, mm0);
movq_m2r (*dest, mm1);
@@ -791,7 +791,7 @@ static inline void MC_avg4_16 (int height, uint8_t * dest, const uint8_t * ref,
movq_r2r (mm0, mm6);
pxor_r2r (mm2, mm6);
pand_r2r (mm6, mm7);
- pand_m2r (mask_one, mm7);
+ pand_m2r (tqmask_one, mm7);
pavg_r2r (mm2, mm0);
psubusb_r2r (mm7, mm0);
movq_m2r (*(dest+8), mm1);